@@ -67,8 +67,8 @@ def load_xyz(f_name:str, atomic_numbers:bool=False):
 
     return _labels, _coords
 
-def save_xyz(f_name:str, labels:list, coords:list, with_numbers:bool=False, verbose:bool=True, mask:list=[], 
-             atomic_numbers:bool=False):
+def save_xyz(f_name:str, labels:list, coords:list, with_numbers:bool=False, 
+             verbose:bool=True, mask:list=[], atomic_numbers:bool=False):
     """
     Add numbers to a list of atomic labels
 
@@ -257,7 +257,9 @@ def formdict_to_formstr(form_dict:dict):
     # Quantities of each element as a string
     # if only 1 of an element then use a blank string
     # as this is how chemical formulae are written
-    form_quants_str = ["{:d}".format(quant) if quant > 1 else "" for quant in form_quants ]
+    form_quants_str = ["{:d}".format(quant) 
+                        if quant > 1 else "" 
+                        for quant in form_quants]
 
     # Sort labels in alphabetical order
     order = np.argsort(form_labels).tolist()
@@ -351,14 +353,17 @@ def get_neighborlist(labels:list, coords:list, adjust_cutoff:dict={}):
                 cutoffs[it] = adjust_cutoff[label]
 
     # Create neighbourlist using cutoffs
-    neigh_list = neighborlist.NeighborList(cutoffs = cutoffs, self_interaction=False, bothways=True)
+    neigh_list = neighborlist.NeighborList(cutoffs = cutoffs, 
+                                           self_interaction=False,
+                                           bothways=True)
 
     # Update this list by specifying the atomic positions
     neigh_list.update(mol)
 
     return neigh_list
 
-def get_adjacency(labels:list, coords:list, adjust_cutoff:dict={}, save:bool=False, f_name:str="adjacency.dat"):
+def get_adjacency(labels:list, coords:list, adjust_cutoff:dict={}, 
+                  save:bool=False, f_name:str="adjacency.dat"):
     """
     Calculate adjacency matrix using ASE built in cutoffs with option to modify them
 
@@ -390,7 +395,8 @@ def get_adjacency(labels:list, coords:list, adjust_cutoff:dict={}, save:bool=Fal
 
     return adjacency
 
-def get_bonds(labels:list, coords:list, neigh_list=None, f_name:str='bonds.dat', save:bool=False,
+def get_bonds(labels:list, coords:list, neigh_list=None, 
+              f_name:str='bonds.dat', save:bool=False,
               verbose:bool=True, style:bool='indices'):
     """
     Calculate and save list of atoms between which there is a bond.
@@ -466,8 +472,9 @@ def get_bonds(labels:list, coords:list, neigh_list=None, f_name:str='bonds.dat',
 
     return bonds
 
-def get_angles(labels:list, coords:list, neigh_list=None, f_name:str='angles.dat', save:bool=False,
-              verbose:bool=True, style:bool='indices'):
+def get_angles(labels:list, coords:list, neigh_list=None,   
+               f_name:str='angles.dat', save:bool=False,
+               verbose:bool=True, style:bool='indices'):
     """
     Calculate and save list of atoms between which there is a bond angle.
     Using ASE. Only unique angles are saved.
@@ -542,8 +549,9 @@ def get_angles(labels:list, coords:list, neigh_list=None, f_name:str='angles.dat
 
     return angles
 
-def get_dihedrals(labels:list, coords:list, neigh_list=None, f_name:str='dihedrals.dat', save:bool=False,
-              verbose:bool=True, style:bool='indices'):
+def get_dihedrals(labels:list, coords:list, neigh_list=None,
+                  f_name:str='dihedrals.dat', save:bool=False,
+                  verbose:bool=True, style:bool='indices'):
     """
     Calculate and save list of atoms between which there is a dihedral.
     Using ASE. Only unique angles are saved.
@@ -704,8 +712,10 @@ def reflect_coords(coords:list):
     return coords
         
 
-def remove_broken(labels:list, coords:list, formulae:list, adjust_cutoff:dict={}, verbose:bool=False,
-                  save:bool = False, frag_f_name:str="fragments.xyz", clean_f_name:str="clean.xyz", 
+def remove_broken(labels:list, coords:list, formulae:list, 
+                  adjust_cutoff:dict={}, verbose:bool=False,
+                  save:bool = False, frag_f_name:str="fragments.xyz", 
+                  clean_f_name:str="clean.xyz", 
                   mask:list=[], skip:list=[]):
     """
     Removes structures from coords which do not match formula in formulae
@@ -714,27 +724,33 @@ def remove_broken(labels:list, coords:list, formulae:list, adjust_cutoff:dict={}
 
     Returns 
         - labels and coordinates of molecules
-            ordered such taht molecules are grouped together and
+            ordered such that molecules are grouped together and
             metal containing molecules are at the top of the coords array
         - labels and coordinates of fragments
-        - dictionary containing indices of complete molecules, where the indices correspond
-          to the original ordering of labels and coords given to this function 
+        - dictionary containing indices of complete molecules, where the indices 
+          correspond to the original ordering of labels and coords given to 
+          this function 
 
     Positional arguments:
         labels (list) : list of atomic labels
         coords (list) : list of lists of xyz coordinates of each atom
-        formulae (list) : list of chemical formulae stored as dictionaries with atomic symbol (key) count (val) pairs
+        formulae (list) : list of chemical formulae stored as dictionaries 
+                          with atomic symbol (key) count (val) pairs
 
     Keyword arguments:
         adjust_cutoff (dict)  : dictionary of atoms (keys) and new cutoffs (values)
         verbose (bool)        : print molecule count to screen
-        save (bool)           : Save molecules and incomplete fragments to separate xyz files
-        frag_f_name (str)     : Name for xyz file containing fragmented structures
+        save (bool)           : Save molecules and incomplete fragments to 
+                                separate xyz files
+        frag_f_name (str)     : Name for xyz file containing fragmented 
+                                structures
         clean_f_name (str)    : Name for xyz file containing full molecules
-        mask (list)           : list of 0 (exclude) and 1 (include) for each element 
-                                - if used, final lists will exclude masked elements
-        skip (list)           : List of atomic indices which shall not be visited when tracing 
-                                 bonding network
+        mask (list)           : list of 0 (exclude) and 1 (include) for each 
+                                element 
+                                - if used, final lists will exclude masked 
+                                  elements
+        skip (list)           : List of atomic indices which shall not be 
+                                visited when tracing bonding network
     Returns:
         labels_clean (list)  : list of atomic labels for full molecules
         coords_clean (list)  : list of lists of xyz coordinates of each atom for full molecules
@@ -991,7 +1007,7 @@ def calculate_rmsd(coords_1:list, coords_2:list, mask_1:list=[], mask_2:list=[],
         _order_1 = range(len(coords_1))
 
     if order_2:
-        _order_2 = _order_2
+        _order_2 = order_2
     else:
         _order_2 = range(len(coords_2))
 
@@ -1095,7 +1111,7 @@ def minimise_rmsd(coords_1:list, coords_2:list, mask_1:list=[], mask_2:list=[],
         _order_1 = range(len(coords_1))
 
     if order_2:
-        _order_2 = _order_2
+        _order_2 = order_2
     else:
         _order_2 = range(len(coords_2))
 
